#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#-------------------------------------------------------------------------------
# Unit tests for org.glite.data.srm-util-cpp
# utility script to start and stop the stub SRM servers
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: stub-srm-servers.sh,v 1.2 2008/07/02 09:45:39 ptedesco Exp $
# Release: $Name:  $
#-------------------------------------------------------------------------------

function check_vars(){
    local i
    for ((i=1;i<=${#};i++)); do
        local name
        local value
        name="${!i}"
        value="${!name}"
        if [ "" == "${value}" ]; then
            error "${FUNCNAME[1]} called with ${name} not defined"
            return 1
        else
            debug "${FUNCNAME[1]} called with ${name}=${value}"
        fi
    done
    return 0
}

#-------------------------------------------------------------------------------
# srm_stub_servers_stub_sd_install
# create the services.xml file for the stub servers
#-------------------------------------------------------------------------------
function srm_stub_servers_stub_sd_install(){
    (check_vars "MODULE_TEST_DIR") || return 1

    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="STUB_1_1_SRM">
    <parameters>
      <endpoint>httpg://localhost:8043/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>CERN</site>
    </parameters>
  </service>
  <service name="STUB_2_2_SRM">
    <parameters>
      <endpoint>httpg://localhost:8044/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2</version>
      <site>CERN</site>
    </parameters>
  </service>
</services>
EOD
    return 0
}

#-------------------------------------------------------------------------------
# srm_stub_servers_stub_server_1_1_install
# create the configuration file for the SRM1.1 stub
#-------------------------------------------------------------------------------
function srm_stub_servers_stub_server_1_1_install(){
    (check_vars "MODULE_TEST_DIR" "SRM_UTIL_CPP_LOCATION") || return 1

    # Create Template for the SRM 1.1 Stub
    create_config_xml "glite-srm-util-stub-server-1_1" "${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml" \
        "${SRM_UTIL_CPP_LOCATION}/config/srm-util-stub-server-1.1.config-template.xml"
    # Create configuration for srm1.1 stub
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.log-properties \
        -O srm-util-stub-server-1_1.Port=8043 \
        -O srm-util-stub-server-1_1.SecureProtocol=gsi \
        -O srm-util-stub-server-1_1.PoolLocation=${MODULE_TEST_DIR}/var/tmp/srm/pool \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.log \
        -O log.Priority=DEBUG
}

#-------------------------------------------------------------------------------
# srm_stub_servers_stub_server_2_2_install
# create the configuration file for the SRM2.2 stub
#-------------------------------------------------------------------------------
function srm_stub_servers_stub_server_2_2_install(){
    (check_vars "MODULE_TEST_DIR" "SRM_UTIL_CPP_LOCATION") || return 1

    # Create Template for the SRM 2.2 Stub
    create_config_xml "glite-srm-util-stub-server-2_2" "${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml" \
        "${SRM_UTIL_CPP_LOCATION}/config/srm-util-stub-server-2.2.config-template.xml"
    # Create configuration for srm2.2 stub
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.log-properties \
        -O srm-util-stub-server-2_2.Port=8044 \
        -O srm-util-stub-server-2_2.SecureProtocol=gsi \
        -O srm-util-stub-server-2_2.PoolLocation=${MODULE_TEST_DIR}/var/tmp/srm/pool \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.log \
        -O log.Priority=DEBUG
}

#-------------------------------------------------------------------------------
# srm_stub_servers_start_stub_servers
# start the stub servers
#-------------------------------------------------------------------------------
function srm_stub_servers_start_stub_servers(){
    (check_vars "MODULE_TEST_DIR" "GLITE_LOCATION") || return 1

    # Kill Previous errors 
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 5
    # Start the SRM 1.1 Stub
    echo "Starting SRM 1.1 Stub..."
    local server11_cgsitracefile="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.cgsi"
    debug "CGSI_TRACE : \"${TESTS_CGSI_TRACE}\""
    debug "CGSI_TRACEFILE=\"${server11_cgsitracefile}\""
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        ${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${server11_cgsitracefile}" \
        ${GLITE_LOCATION}/bin/glite_data_config_service -v glite-srm-util-stub-server-1.1 start) || return ${?}
    #config_service glite-srm-util-stub-server-1.1 start || return ${?}
    echo "SRM 1.1 Stub Started"
    # start SRM2.2 stub
    echo "Starting SRM 2.2 Stub..."
    local server22_cgsitracefile="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.cgsi"
    debug "CGSI_TRACE : \"${TESTS_CGSI_TRACE}\""
    debug "CGSI_TRACEFILE=\"${server22_cgsitracefile}\""
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        ${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${server22_cgsitracefile}" \
        ${GLITE_LOCATION}/bin/glite_data_config_service -v glite-srm-util-stub-server-2.2 start) || return ${?}
    #config_service glite-srm-util-stub-server-2.2 start || return ${?}
    echo "SRM 2.2 Stub Started"
    return 0

    # kill previous errors
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 5
    # start SRM1.1 stub
    config_service glite-srm-util-stub-server-1.1 start || return ${?}
    echo "SRM 1.1 Stub Started"
    # start SRM2.2 stub
    config_service glite-srm-util-stub-server-2.2 start || return ${?}
    echo "SRM 2.2 Stub Started"

}

#-------------------------------------------------------------------------------
# srm_stub_servers_stop_stub_servers
# stop the stub servers
#-------------------------------------------------------------------------------
function srm_stub_servers_stop_stub_servers(){
    echo "Stopping SRM 2.2 Stub..."
    config_service glite-srm-util-stub-server-2.2 stop
    echo "SRM 2.2 Stub Stopped."
    echo "Stopping SRM 1.1 Stub..."
    config_service glite-srm-util-stub-server-1.1 stop
    echo "SRM 1.1 Stub Stopped."
}

